# -*- coding: utf-8 -*-
"""
Created on Mon Sep 28 14:50:34 2020

@author: rusli001
"""

import pandas as pd
import numpy as np
import datetime as dt
import matplotlib.pyplot as plt
import matplotlib.dates as md
from scipy import stats

# import rainfall runoff data
grace = pd.read_excel('GRACE data.xlsx', sheet_name = 'with CRI')
grace_ = grace['TWS (mm/day)'].values
time = grace['Date'].values

# plot simulation vs observation
fig, (ax1, ax2) = plt.subplots(2, figsize = (16,10))
ax1.plot_date(time, grace_, fmt = 'o-', xdate = True, ydate = False, label = 'GLEAM', color = 'black', linewidth = 0.5)
ax2.plot_date(time, grace_, fmt = 'o-', xdate = True, ydate = False, label = 'GLEAM', color = 'black', linewidth = 0.5)

# set first trendline
grace_1 = grace_[0:80]
trendline_1 = stats.linregress(range(len(time[0:80])), grace_1)
ax1.plot(md.date2num(time[0:80]), np.poly1d(np.polyfit(md.date2num(time[0:80]), grace_1, 1))(md.date2num(time[0:80])),
         'r--', label = 'linear regression')
ax1.annotate('consistent average of TWSC', xy = (dt.date(2006,1,1), 0.25), xytext = (dt.date(2005,4,1), -3.5),
            arrowprops = dict(width = 0.5, headwidth = 5, color = 'r', shrink = 0.05))

# set second trendline
grace_2 = grace_[82:138]
trendline_2 = stats.linregress(range(len(time[82:138])), grace_2)
ax2.plot(md.date2num(time[82:138]), np.poly1d(np.polyfit(md.date2num(time[82:138]), grace_2, 1))(md.date2num(time[82:138])),
         'b--', label = 'linear regression')
ax2.annotate('increasing trend of TWSC', xy = (dt.date(2013,7,2), 1.25), xytext = (dt.date(2012,4,1), -3.5),
            arrowprops = dict(width = 0.5, headwidth = 5, color = 'b', shrink = 0.05))

# configure x1 axes
ax1.set_xlim([dt.date(2005,1,1), dt.date(2012,1,1)])
xfmt = md.DateFormatter('%m-%Y')
ax1.xaxis.set_major_formatter(xfmt)
yloc = md.YearLocator()
ax1.xaxis.set_major_locator(yloc)
plt.xlabel('date')

# configure y1 axes
evaporation_ticks = np.arange(-8,10,2)
ax1.set_yticks(evaporation_ticks)
ax1.set_ylim(-8,8)
ax1.set_ylabel('Terrestrial water storage change (mm/day)')
ax1.grid(which = 'major', color = 'grey', linestyle = ':', linewidth = 0.3)

# configure x2 axes
ax2.set_xlim([dt.date(2012,1,1), dt.date(2019,1,1)])
xfmt = md.DateFormatter('%m-%Y')
ax2.xaxis.set_major_formatter(xfmt)
yloc = md.YearLocator()
ax2.xaxis.set_major_locator(yloc)
plt.xlabel('date')

# configure y2 axes
evaporation_ticks = np.arange(-8,10,2)
ax2.set_yticks(evaporation_ticks)
ax2.set_ylim(-8,8)
ax2.set_ylabel('Terrestrial water storage change (mm/day)')
ax2.grid(which = 'both', color = 'grey', linestyle = ':', linewidth = 0.3)

# hatch seasonal change
ax1.axvspan(dt.date(2005,1,1), dt.date(2005,3,31), alpha = 0.05, color = 'gray')
#ax1.axvspan(dt.date(2005,4,1), dt.date(2005,9,30), alpha = 0.05, color = 'red')
ax1.axvspan(dt.date(2005,10,1), dt.date(2006,3,31), alpha = 0.05, color = 'gray')
#ax1.axvspan(dt.date(2006,4,1), dt.date(2006,9,30), alpha = 0.05, color = 'red')
ax1.axvspan(dt.date(2006,10,1), dt.date(2007,3,31), alpha = 0.05, color = 'gray')
#ax1.axvspan(dt.date(2007,4,1), dt.date(2007,9,30), alpha = 0.05, color = 'red')
ax1.axvspan(dt.date(2007,10,1), dt.date(2008,3,31), alpha = 0.05, color = 'gray')
#ax1.axvspan(dt.date(2008,4,1), dt.date(2008,9,30), alpha = 0.05, color = 'red')
ax1.axvspan(dt.date(2008,10,1), dt.date(2009,3,31), alpha = 0.05, color = 'gray')
#ax1.axvspan(dt.date(2009,4,1), dt.date(2009,9,30), alpha = 0.05, color = 'red')
ax1.axvspan(dt.date(2009,10,1), dt.date(2010,3,31), alpha = 0.05, color = 'gray')
#ax1.axvspan(dt.date(2010,4,1), dt.date(2010,9,30), alpha = 0.05, color = 'red')
ax1.axvspan(dt.date(2010,10,1), dt.date(2011,3,31), alpha = 0.05, color = 'gray')
#ax1.axvspan(dt.date(2011,4,1), dt.date(2011,9,30), alpha = 0.05, color = 'red')
ax1.axvspan(dt.date(2011,10,1), dt.date(2011,12,31), alpha = 0.05, color = 'gray')
ax2.axvspan(dt.date(2012,1,1), dt.date(2012,3,31), alpha = 0.05, color = 'gray')
#ax2.axvspan(dt.date(2012,4,1), dt.date(2012,9,30), alpha = 0.05, color = 'red')
ax2.axvspan(dt.date(2012,10,1), dt.date(2013,3,31), alpha = 0.05, color = 'gray')
#ax2.axvspan(dt.date(2013,4,1), dt.date(2013,9,30), alpha = 0.05, color = 'red')
ax2.axvspan(dt.date(2013,10,1), dt.date(2014,3,31), alpha = 0.05, color = 'gray')
#ax2.axvspan(dt.date(2014,4,1), dt.date(2014,9,30), alpha = 0.05, color = 'red')
ax2.axvspan(dt.date(2014,10,1), dt.date(2015,3,31), alpha = 0.05, color = 'gray')
#ax2.axvspan(dt.date(2015,4,1), dt.date(2015,9,30), alpha = 0.05, color = 'red')
ax2.axvspan(dt.date(2015,10,1), dt.date(2016,3,31), alpha = 0.05, color = 'gray')
#ax2.axvspan(dt.date(2016,4,1), dt.date(2016,9,30), alpha = 0.05, color = 'red')
ax2.axvspan(dt.date(2016,10,1), dt.date(2017,3,31), alpha = 0.05, color = 'gray')
#ax2.axvspan(dt.date(2017,4,1), dt.date(2017,9,30), alpha = 0.05, color = 'red')
ax2.axvspan(dt.date(2017,10,1), dt.date(2018,3,31), alpha = 0.05, color = 'gray')
#ax2.axvspan(dt.date(2018,4,1), dt.date(2018,9,30), alpha = 0.05, color = 'red')
ax2.axvspan(dt.date(2018,10,1), dt.date(2019,12,31), alpha = 0.05, color = 'gray')

# draw arrows
red_prop =  dict(arrowstyle="-|>, head_width = 0.2, head_length = 0.3", shrinkA = 0, shrinkB = 0, color = 'red')
ax1.annotate("", xy = (dt.date(2005,7,30), 6.5), xytext = (dt.date(2005,6,1), 7.5), arrowprops = red_prop)
ax1.annotate("", xy = (dt.date(2006,7,30), 6.5), xytext = (dt.date(2006,6,1), 7.5), arrowprops = red_prop)
ax1.annotate("", xy = (dt.date(2007,7,30), 6.5), xytext = (dt.date(2007,6,1), 7.5), arrowprops = red_prop)
ax1.annotate("", xy = (dt.date(2008,7,30), 6.5), xytext = (dt.date(2008,6,1), 7.5), arrowprops = red_prop)
ax1.annotate("", xy = (dt.date(2009,7,30), 6.5), xytext = (dt.date(2009,6,1), 7.5), arrowprops = red_prop)
ax1.annotate("", xy = (dt.date(2011,1,31), 6.5), xytext = (dt.date(2010,12,1), 7.5), arrowprops = red_prop)
ax1.annotate("", xy = (dt.date(2011,7,30), 6.5), xytext = (dt.date(2011,6,1), 7.5), arrowprops = red_prop)
ax2.annotate("", xy = (dt.date(2012,7,30), 6.5), xytext = (dt.date(2012,6,1), 7.5), arrowprops = red_prop)
ax2.annotate("", xy = (dt.date(2013,7,30), 6.5), xytext = (dt.date(2013,6,1), 7.5), arrowprops = red_prop)
ax2.annotate("", xy = (dt.date(2014,7,30), 6.5), xytext = (dt.date(2014,6,1), 7.5), arrowprops = red_prop)
ax2.annotate("", xy = (dt.date(2015,7,30), 6.5), xytext = (dt.date(2015,6,1), 7.5), arrowprops = red_prop)
ax2.annotate("", xy = (dt.date(2016,7,30), 6.5), xytext = (dt.date(2016,6,1), 7.5), arrowprops = red_prop)
ax2.annotate("", xy = (dt.date(2017,7,30), 6.5), xytext = (dt.date(2017,6,1), 7.5), arrowprops = red_prop)
blue_prop =  dict(arrowstyle="-|>, head_width = 0.2, head_length = 0.3", shrinkA = 0, shrinkB = 0, color = 'blue')
ax1.annotate("", xy = (dt.date(2006,1,31), 7.5), xytext = (dt.date(2005,12,1), 6.5), arrowprops = blue_prop)
ax1.annotate("", xy = (dt.date(2007,1,31), 7.5), xytext = (dt.date(2006,12,1), 6.5), arrowprops = blue_prop)
ax1.annotate("", xy = (dt.date(2008,1,31), 7.5), xytext = (dt.date(2007,12,1), 6.5), arrowprops = blue_prop)
ax1.annotate("", xy = (dt.date(2009,1,31), 7.5), xytext = (dt.date(2008,12,1), 6.5), arrowprops = blue_prop)
ax1.annotate("", xy = (dt.date(2010,1,31), 7.5), xytext = (dt.date(2009,12,1), 6.5), arrowprops = blue_prop)
ax1.annotate("", xy = (dt.date(2010,7,30), 7.5), xytext = (dt.date(2010,6,1), 6.5), arrowprops = blue_prop)
ax2.annotate("", xy = (dt.date(2013,1,31), 7.5), xytext = (dt.date(2012,12,1), 6.5), arrowprops = blue_prop)
ax2.annotate("", xy = (dt.date(2014,1,31), 7.5), xytext = (dt.date(2013,12,1), 6.5), arrowprops = blue_prop)
ax2.annotate("", xy = (dt.date(2015,1,25), 7.5), xytext = (dt.date(2014,12,1), 6.5), arrowprops = blue_prop)
ax2.annotate("", xy = (dt.date(2016,1,31), 7.5), xytext = (dt.date(2015,12,1), 6.5), arrowprops = blue_prop)
ax2.annotate("", xy = (dt.date(2017,1,31), 7.5), xytext = (dt.date(2016,12,1), 6.5), arrowprops = blue_prop)

# draw x axis at y = 0
ax1.axhline(y = 0, color = 'black', linewidth = 0.5, alpha = 0.5)
ax2.axhline(y = 0, color = 'black', linewidth = 0.5, alpha = 0.5)

# save to pdf
#plt.savefig("grace_estimates.jpg", dpi = 300, bbox_inches = 'tight')
plt.show()