# -*- coding: utf-8 -*-
"""
Created on Mon Sep 28 14:50:34 2020

@author: rusli001
"""

import pandas as pd
import math as math
import numpy as np
import datetime as dt
import matplotlib.pyplot as plt
import matplotlib.dates as md

# import TWSC data
uncertainty = pd.read_excel('3 - Layer-based water balance.xlsx', sheet_name = 'uncertainty')
time = uncertainty['Date'].values
up_out = uncertainty['up_out'].values
up_in = uncertainty['up_in'].values
low_out = uncertainty['low_out'].values
low_in = uncertainty['low_in'].values

# plot simulation vs observation
fig, ax = plt.subplots(figsize = (15,6))
ax.plot_date(time, up_in, fmt = 'o-', xdate = True, ydate = False, color = 'red', label = 'Estimated lay1 storage loss due to inter-aquifer interaction', linewidth = 0.5, markersize = 1)
ax.plot_date(time, low_in, fmt = 'o-', xdate = True, ydate = False, color = 'green', label = 'Estimated lay3 storage gain due to inter-aquifer interaction', linewidth = 0.5, markersize = 1)
ax.fill_between(time, up_in, up_out, color = 'blue', alpha = 0.1)
ax.fill_between(time, low_in, low_out, color = 'blue', alpha = 0.1)
ax.fill_between(time, up_in, low_in, color = 'darkblue', alpha = 0.1, interpolate = True, label = 'Uncertainty bounds')

# configure x1 axes
ax.set_xlim([dt.date(2005,1,1), dt.date(2019,1,1)])
xfmt = md.DateFormatter('%Y')
ax.xaxis.set_major_formatter(xfmt)
yloc = md.YearLocator()
ax.xaxis.set_major_locator(yloc)

# configure y1 axes
axis_ticks = np.arange(-1,1,0.1)
ax.set_yticks(axis_ticks)
ax.set_ylim(-0.6,0.6)
ax.set_ylabel('Groundwater storage change (mm/day)')
ax.grid(which = 'major', color = 'grey', linestyle = ':', linewidth = 0.3)

# configure legend
ax.legend(loc = 2)

# save to pdf
plt.savefig("aquiferinteraction_uncertainty.pdf", dpi = 300, bbox_inches = 'tight')
plt.show()