# -*- coding: utf-8 -*-
"""
Created on Mon Sep 28 14:50:34 2020

@author: rusli001
"""

import pandas as pd
import math as math
import numpy as np
import datetime as dt
import matplotlib.pyplot as plt
import matplotlib.dates as md

# import TWSC data
lay3 = pd.read_excel('3 - Layer-based water balance.xlsx', sheet_name = 'Layer3')
time_lay3 = lay3['Date'].values
remainder_lay3 = lay3['WEL (m/day)']
sto_lay3 = lay3['sto_ss (m/day)'].values

# plot simulation vs observation
fig, ax = plt.subplots(figsize = (15,6))
ax.plot_date(time_lay3, sto_lay3, fmt = 'o-', xdate = True, ydate = False, color = 'magenta', label = 'Simulated total water storage change in the lower aquifer', linewidth = 0.5, markersize = 1)
ax.plot_date(time_lay3, remainder_lay3, fmt = 'o-', xdate = True, ydate = False, color = 'green', label = 'Remainder of mass balance in the lower aquifer (- abstraction)', linewidth = 0.5, markersize = 1)
ax.fill_between(time_lay3, remainder_lay3, sto_lay3, where = remainder_lay3 < sto_lay3,
                color = 'blue', alpha = 0.1, interpolate = True, label = 'Estimated lay3 storage gain due to inter-aquifer interaction')

# configure x1 axes
ax.set_xlim([dt.date(2005,1,1), dt.date(2019,1,1)])
xfmt = md.DateFormatter('%Y')
ax.xaxis.set_major_formatter(xfmt)
yloc = md.YearLocator()
ax.xaxis.set_major_locator(yloc)

# configure y1 axes
axis_ticks = np.arange(-1,1,0.1)
ax.set_yticks(axis_ticks)
ax.set_ylim(-0.6,0.6)
ax.set_ylabel('Groundwater storage change (mm/day)')
ax.grid(which = 'major', color = 'grey', linestyle = ':', linewidth = 0.3)

# configure legend
ax.legend(loc = 2)

# save to pdf
plt.savefig("aquiferinteraction_lay3.pdf", dpi = 300, bbox_inches = 'tight')
plt.show()