# -*- coding: utf-8 -*-
"""
Created on Mon Sep 12 14:45:23 2022

@author: rusli001
"""

import pandas as pd
import numpy as np
import matplotlib.pyplot as plt

# import groundwater head data
rain_data = pd.read_excel('data_isotop.xlsx', sheet_name = 'air hujan')
rain_o = rain_data['18O'].values
rain_h = rain_data['2H'].values

river_data = pd.read_excel('data_isotop.xlsx', sheet_name = 'sungai')
river_o = river_data['18O'].values
river_h = river_data['2H'].values

shallow_data = pd.read_excel('data_isotop.xlsx', sheet_name = 'sumur gali')
shallow_o = shallow_data['18O'].values
shallow_h = shallow_data['2H'].values

deep_data = pd.read_excel('data_isotop.xlsx', sheet_name = 'sumur bor')
deep_o = deep_data['18O'].values
deep_h = deep_data['2H'].values

# global meteoric water line
y = np.linspace(-86,10,100)
x = 8*y + 10

# plot observation vs simulation
fig, ax = plt.subplots(figsize = (8,8))
plt.grid(axis = 'both', which = 'major', alpha = 0.5)
plt.plot(y, x, '-', color = 'orange', label = 'Global Meteoric Water Line (GWML)')
ax.scatter(rain_o, rain_h, c = 'black', label = 'Rainfall')
z = np.polyfit(rain_o, rain_h, 1)
p = np.poly1d(z)
plt.plot(rain_o, p(rain_o), "k--", dashes = (1,5))
ax.scatter(river_o, river_h, c = 'green', label = 'River')
z = np.polyfit(river_o, river_h, 1)
p = np.poly1d(z)
plt.plot(river_o, p(river_o), "g--", dashes = (1,5))
ax.scatter(shallow_o, shallow_h, c = 'blue', label = 'Shallow groundwater')
z = np.polyfit(shallow_o, shallow_h, 1)
p = np.poly1d(z)
plt.plot(shallow_o, p(shallow_o), "b--", dashes = (1,5))
ax.scatter(deep_o, deep_h, c = 'red', label = 'Deep groundwater')
z = np.polyfit(deep_o, deep_h, 1)
p = np.poly1d(z)
plt.plot(deep_o, p(deep_o), "r--", dashes = (1,5))
plt.xlabel('$\delta_{18}$O (‰)')
plt.ylabel('$\delta_{2}$H (‰)')
ax.set_xlim(-10,-4)
ax.set_ylim(-70,-20)
ax.legend(loc = 4)

plt.savefig("isotop_data.pdf", dpi = 300, bbox_inches = 'tight')
fig.show()